@@ -63,14 +63,14 @@ static gboolean cupboard_composition_icon_clicked(TangleButton *tanglebutton, gp
 	clutter_actor_hide(actor);
 
 	//We do not want Mentor say "welcome to composing", when loading saved composing.
-	jammo_mentor_speak_once(jammo_mentor_get_default(), "composing_welcome.ogg");
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "composing_welcome.spx");
 
 	//We do not want Mentor to help "select theme" anymore, when player have went in composing game
-	jammo_mentor_speak_once(jammo_mentor_get_default(), "themeselection_welcome.ogg");
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "themeselection_welcome.spx");
 	
 	//We do not want Mentor to help when first samplebutton is clicked or dragged
-	jammo_mentor_speak_once(jammo_mentor_get_default(), "composing_first_drag.ogg");
-	jammo_mentor_speak_once(jammo_mentor_get_default(), "composing_first_click.ogg");
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "composing_first_drag.spx");
+	jammo_mentor_speak_once(jammo_mentor_get_default(), "composing_first_click.spx");
 	jammo_mentor_shut_up(jammo_mentor_get_default());
 	
 	gchar *filename; 
@@ -282,7 +282,7 @@ static void load_icons_from_disk (){
 		song->language = language;
 		song_prepare_icon(song);
 
-		//song->name_of_recorded = g_strdup_printf("%s/vocal_fi.ogg",fullpath); //DEBUG
+		//song->name_of_recorded = g_strdup_printf("%s/vocal_fi.spx",fullpath); //DEBUG
 
 		//Next section has lots of common with singingame.c:~300 FIXME
 		gfloat icon_size = 78.0;    //square
@@ -391,8 +391,8 @@ cupboard_door_clicked(NULL,NULL,NULL,NULL);
 void cupboard_start_cupboard(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	printf("cupboard_start_cupboard\n");
 	load_icons_from_disk(); //This is not needed if we are coming from listening. TODO
-	jammo_mentor_speak_once_with_callback(jammo_mentor_get_default(),"cupboard_welcome.ogg",mentor_over,NULL);
-	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "cupboard_welcome.ogg");
+	jammo_mentor_speak_once_with_callback(jammo_mentor_get_default(),"cupboard_welcome.spx",mentor_over,NULL);
+	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "cupboard_welcome.spx");
 }
 
 //This is callback for json.
