@@ -203,8 +203,10 @@ void fullsequencer_loop_crazy_clicked (TangleAction *action, GObject *source, co
 //////////////////////////////////////
 
 //Bottom of the loop-view there are dropping-area, and when samplebutton is dragged here, view is changed.
-void sequencer_handle_dragging (TangleDroppableActor *droppable_actor, TangleDragging *dragging){
+gboolean sequencer_handle_dragging (TangleDroppableActor *droppable_actor, TangleDragging *dragging){
 	sequencer_change_to_sequencer_view(NULL,NULL);
+	
+	return FALSE;
 }
 
 
