@@ -14,6 +14,7 @@ And then sequencer_track_view_add_with_type(sequencerTrackViewTYpe)
 #include "../../meam/jammo-track.h"
 #include "../../meam/jammo-editing-track.h"
 #include "../../meam/jammo-instrument-track.h"
+#include "../../meam/jammo-slider-track.h"
 #include "../../meam/jammo-midi.h"
 #include "../../meam/jammo-meam.h" //JAMMO_DURATION_INVALID
 
@@ -40,89 +41,20 @@ static ClutterActor* texture_of_cursor;
 static SequencerTrackView *track_views[6] = {NULL};
 static gint tracks_in_use = 0;
 
-
-//All tracks share these
-static ClutterActor *TEXTURE_VOLUME_BACKGROUND;
-static ClutterActor *BUTTON_VOLUME_SLIDER;
-
 static JammoSequencer* sequencer; // for playing the tracks;
 
 static gfloat VOLUME_MAX = 100; //? FIX
 
-static gint BUTTON_SEQUENCER_VOLUME_ACTIVE = -1; //which volume button is pressed down
-
-static gboolean volume_slider_is_dragging = FALSE;
-static gboolean volume_background_is_dragging = FALSE;
-
 static gboolean METRONOME_STATE = FALSE;
 
-static void get_volume_background_coords(gfloat *position_x, gfloat *position_y);
+
 static gboolean pressed_sequencer_button_mute(ClutterActor *actor, ClutterEvent *event, gpointer data);
 static ClutterAnimation * animate_buttonpress_release(ClutterActor *actor);
 static gboolean pressed_sequencer_button_volume(ClutterActor *actor, ClutterEvent *event, gpointer data);
 static gboolean pressed_sequencer_button_track_label(ClutterActor *actor, ClutterEvent *event, gpointer data);
-static void move_volume_slider(ClutterEvent *event);
 
-static SequencerTrackView *get_active_volume_button_track_view() {
-	int i;
-	for(i = 0; i < tracks_in_use; i++) {
-		if(track_views[i]->volume_pressed_down == TRUE)
-			return track_views[i];
-	}
-	return NULL;
-}
 
-static void pressed_sequencer_volume_background (ClutterActor *actor, ClutterEvent *event, gpointer data) {
 
-	volume_background_is_dragging = TRUE;
-	clutter_grab_pointer(CLUTTER_ACTOR(actor));
-
-	move_volume_slider(event);
-}
-
-static void pressed_sequencer_button_volume_slider (ClutterActor *actor, ClutterEvent *event, gpointer data) {
-
-	volume_slider_is_dragging = TRUE;
-
-	clutter_grab_pointer(CLUTTER_ACTOR(actor));
-
-	move_volume_slider(event);
-
-}
-
-static void released_sequencer_button_volume_slider (ClutterActor *actor, ClutterEvent *event, gpointer data) {
-
-	volume_slider_is_dragging = FALSE;
-	clutter_ungrab_pointer();
-
-}
-
-static void released_sequencer_volume_background (ClutterActor *actor, ClutterEvent *event, gpointer data) {
-
-	volume_background_is_dragging = FALSE;
-	clutter_ungrab_pointer();
-
-}
-
-static void motion_sequencer_volume_background (ClutterActor *actor, ClutterEvent *event, gpointer data) {
-
-	if (volume_background_is_dragging) {
-
-		move_volume_slider(event);
-
-	}
-
-}
-
-static void motion_sequencer_button_volume_slider (ClutterActor *actor, ClutterEvent *event, gpointer data) {
-
-	if (volume_slider_is_dragging) {
-
-		move_volume_slider(event);
-
-	}
-
-}
 
 
 /*
@@ -251,9 +183,12 @@ ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type ) {
 	//Make instrument_track and miditrack_view
 	if (strncmp(track_view_type,"KEYBOARD_TRACK_VIEW",19)==0)
 		{
-		track = JAMMO_TRACK(jammo_instrument_track_new(JAMMO_INSTRUMENT_TYPE_UD));
+		track = JAMMO_TRACK(jammo_instrument_track_new(JAMMO_INSTRUMENT_TYPE_UD)); //TODO. instrument_type
 		jammo_instrument_track_set_realtime(JAMMO_INSTRUMENT_TRACK(track),FALSE);
 
+		// TODO set transpose. Key of the song should be stored somewhere
+		instrument_gui_set_transpose('c');
+
 		//TODO: we need to know highest_note and lowest_note for this instrument!
 		track_view_actor = jammo_miditrack_view_new(JAMMO_INSTRUMENT_TRACK(track),
           number_of_slots, duration_of_one_slot, width_of_slot, track_height,60,24); //height can be anything, we zoom it
@@ -262,6 +197,18 @@ ClutterActor* sequencer_track_view_add_with_type(gchar* track_view_type ) {
 		}
 
 
+
+	//Make slider_track and container for it
+	else if (strncmp(track_view_type,"SLIDER_TRACK_VIEW",13)==0)
+		{
+		track = JAMMO_TRACK(jammo_slider_track_new(JAMMO_SLIDER_TYPE_KARPLUS));//TODO. instrument_type
+		jammo_instrument_track_set_realtime(JAMMO_INSTRUMENT_TRACK(track),FALSE);
+
+		track_view_actor = tangle_widget_new();
+		g_object_set_data (G_OBJECT(track_view_actor),"track",track);
+		//TODO: set size and some visualization.
+		}
+
 	//Make editing_track and track_view
 	else
 	{
@@ -322,11 +269,17 @@ static gboolean pressed_sequencer_button_track_label(ClutterActor *actor, Clutte
 		//TODO: some way to go straight to editor.
 
 		//jamming
-		instrument_gui_start(JAMMO_MIDITRACK_VIEW(track->track_view),sequencer,FALSE); //slider=FALSE
+		instrument_gui_start(JAMMO_MIDITRACK_VIEW(track->track_view),sequencer, NULL); //NULL means no slider
 
 		//editor
 		//midi_editor_start_with_miditrack_view(JAMMO_MIDITRACK_VIEW(track->track_view));
 	}
+	else if (TANGLE_IS_WIDGET(track->track_view))
+	{
+		printf("It is slider track\n");
+		instrument_gui_start(NULL,sequencer, TANGLE_WIDGET(track->track_view)); //NULL means no keyboard, but slider
+	}
+
 	return TRUE;
 }
 
@@ -362,140 +315,64 @@ static gboolean pressed_sequencer_button_mute(ClutterActor *actor, ClutterEvent
 }
 
 
-static void set_volume_slider_position_by_state(gint state) {
 
-	gfloat position_x_volume_background = 0.0;
-	gfloat position_y_volume_background = 0.0;
-	get_volume_background_coords(&position_x_volume_background, &position_y_volume_background);
+/**
+This syncs scrollers offset to tracks volume.
+*/
+gboolean sequencer_volumebar_used (ClutterActor *volume_scroller, gpointer none){
+	//-80 is height of the visible marker.
+	gfloat height = clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-80;
+	gfloat offset;
+	g_object_get(volume_scroller, "scrolling-offset-y", &offset,NULL);
+	//printf("height %f, offset :%f, ratio %f\n",height, offset,offset/height);
 
-	//get volume background size
-	gfloat volume_background_width = 0;
-	gfloat volume_background_height = 0;
-	clutter_actor_get_size (TEXTURE_VOLUME_BACKGROUND, &volume_background_width, &volume_background_height);
-
-	//get volume slider size
-	gfloat volume_slider_width = 0;
-	gfloat volume_slider_height = 0;
-	clutter_actor_get_size (BUTTON_VOLUME_SLIDER, &volume_slider_width, &volume_slider_height);
-
-	//vertical range of volume background
-	gfloat v_range = volume_background_height - volume_slider_height;
-
-	//volume range is 0..VOLUME_MAX
-	//calculate slider position
-	gfloat position_x_volume_slider = position_x_volume_background + 2;
-	gfloat position_y_volume_slider = position_y_volume_background + (v_range - state);
-
-	clutter_actor_set_position (BUTTON_VOLUME_SLIDER, position_x_volume_slider, position_y_volume_slider);
+	JammoPlayingTrack* jammotrack = g_object_get_data(G_OBJECT(volume_scroller),"track");
 
+	jammo_playing_track_set_volume(jammotrack,offset/height);
+	//printf("new volume:%f\n",offset/height);
+	return FALSE;
 }
 
-static void get_volume_background_coords(gfloat *position_x, gfloat *position_y) {
 
-	gfloat position_x_volume_background = clutter_actor_get_x(track_views[BUTTON_SEQUENCER_VOLUME_ACTIVE]->volume_button);
-	gfloat position_y_volume_background = clutter_actor_get_y(track_views[BUTTON_SEQUENCER_VOLUME_ACTIVE]->control_panel);
-	//get the width of volume button
-	gfloat volume_button_width = 0;
-	gfloat volume_button_height = 0;
-
-	clutter_actor_get_size (track_views[BUTTON_SEQUENCER_VOLUME_ACTIVE]->volume_button, &volume_button_width, &volume_button_height);
-
-	position_x_volume_background += volume_button_width + 2;
-
-	*position_x = position_x_volume_background;
-	*position_y = position_y_volume_background;
-
-}
 
+/**
+Each tracks share one volumebar.
+*/
 static gboolean pressed_sequencer_button_volume(ClutterActor *actor, ClutterEvent *event, gpointer data) {
 	SequencerTrackView *track_view = (SequencerTrackView*) data;
 
-	//if selected button was in normal state (not pressed down)
-	if (track_view->volume_pressed_down == FALSE) {
+	ClutterActor* volume_container = jammo_get_actor_by_id("fullsequencer-volumebar-container");
+	ClutterActor* volume_scroller = jammo_get_actor_by_id("fullsequencer-volumebar-scroller");
+	JammoPlayingTrack* jammotrack;
 
-		//release already pressed button
-		if(BUTTON_SEQUENCER_VOLUME_ACTIVE > -1)
-			animate_buttonpress_release(track_views[BUTTON_SEQUENCER_VOLUME_ACTIVE]->volume_button);
-		//set state pressed
-		track_view->volume_pressed_down = TRUE;
-		BUTTON_SEQUENCER_VOLUME_ACTIVE = track_view->position;
-		//Push selected volume button down
-		//use general animate function
-		animate_buttonpress_down(track_view->volume_button);
+	//slider track is inside tangle_widget, midi- and loop-tracks are inside of jammo-*track-view
+	if (TANGLE_IS_WIDGET(track_view->track_view))
+		jammotrack = JAMMO_PLAYING_TRACK(g_object_get_data(G_OBJECT(track_view->track_view),"track"));
+	else
+		g_object_get(track_view->track_view, "track", &jammotrack, NULL);
 
-		//Open volume slider next to selected button
-		clutter_actor_show(BUTTON_VOLUME_SLIDER);
-
-		clutter_actor_show(TEXTURE_VOLUME_BACKGROUND);
-		clutter_actor_raise_top(TEXTURE_VOLUME_BACKGROUND);
-		clutter_actor_raise_top(BUTTON_VOLUME_SLIDER);
-		//get selected volume button coords
-		gfloat position_x_volume_background = 0.0;
-		gfloat position_y_volume_background = 0.0;
-
-		get_volume_background_coords(&position_x_volume_background, &position_y_volume_background);
-
-		//set volume background to new position
-		clutter_actor_set_position (TEXTURE_VOLUME_BACKGROUND, position_x_volume_background, position_y_volume_background);
-
-		//set the volume slider in its current position
-		set_volume_slider_position_by_state(track_view->volume_level);
-
-	} else {
+	gfloat current_volume = jammo_playing_track_get_volume(jammotrack);
+	//printf("volume of this track is :%f\n",current_volume);
 
 
-		//selected volume button was down - set it to normal state
-		//use general animate function
-		animate_buttonpress_release(track_view->volume_button);
-
-		track_view->volume_pressed_down = FALSE;
-
-		clutter_actor_hide(BUTTON_VOLUME_SLIDER);
-		clutter_actor_hide(TEXTURE_VOLUME_BACKGROUND);
+	//When pressing already selected track, hide volume bar
+	JammoPlayingTrack* jammotrack_in_use = g_object_get_data(G_OBJECT(volume_scroller),"track");
+	if (jammotrack == jammotrack_in_use) {
+		clutter_actor_hide(volume_container);
+		g_object_set_data(G_OBJECT(volume_scroller),"track",NULL);
 	}
 
-	return TRUE;
-}
 
-static void move_volume_slider(ClutterEvent *event) {
+	else {
+		clutter_actor_show(volume_container);
+		//-80 is height of the visible marker.
+		gfloat new_place = (clutter_actor_get_height(CLUTTER_ACTOR(volume_scroller))-80)*current_volume;
+		//printf("new place: %f\n",new_place);
+		clutter_actor_animate(CLUTTER_ACTOR(volume_scroller), CLUTTER_EASE_IN_OUT_QUAD, 250, "scrolling-offset-y", new_place, NULL);
+		g_object_set_data(G_OBJECT(volume_scroller),"track",jammotrack);
+		}
 
-	SequencerTrackView *track_view = get_active_volume_button_track_view();
-	JammoTrack* jammotrack;
-	g_object_get(track_view->track_view, "track", &jammotrack, NULL);
-	if (!jammotrack)
-		return;
-
-	gfloat x_mouse_f,y_mouse_f;
-	clutter_event_get_coords (event, &x_mouse_f, &y_mouse_f);
-
-	//get selected volume button coords
-	gfloat position_x_volume_background_f = 0.0;
-	gfloat position_y_volume_background_f = 0.0;
-	get_volume_background_coords(&position_x_volume_background_f, &position_y_volume_background_f);
-
-	gint position_x_volume_background = (gint)position_x_volume_background_f;
-	gint position_y_volume_background = (gint)position_y_volume_background_f;
-
-	gint new_x, new_y;
-
-	new_x=position_x_volume_background + 2 ;
-	new_y=(gint)y_mouse_f - clutter_actor_get_height(BUTTON_VOLUME_SLIDER) / 2;;
-
-	//Check top and bottom edges
-	gint slide_width = clutter_actor_get_height(TEXTURE_VOLUME_BACKGROUND) - clutter_actor_get_height(BUTTON_VOLUME_SLIDER);
-
-	gint top_edge = position_y_volume_background;
-	gint bottom_edge = position_y_volume_background + slide_width;
-
-	if (new_y < top_edge) new_y = top_edge;
-	if (new_y > bottom_edge) new_y = bottom_edge;
-
-	gint new_volume_state = new_y - position_y_volume_background;
-	//update volume state
-	get_active_volume_button_track_view()->volume_level = VOLUME_MAX - new_volume_state;
-
-	clutter_actor_set_position (CLUTTER_ACTOR(BUTTON_VOLUME_SLIDER), new_x, new_y);
-	jammo_playing_track_set_volume(JAMMO_PLAYING_TRACK(jammotrack), (gfloat)get_active_volume_button_track_view()->volume_level/100);
+	return FALSE;
 }
 
 
@@ -688,27 +565,6 @@ void sequencer_track_view_create_area_for_tracks(JammoSequencer* seq, guint n_sl
 	tangle_signal_connect_vault(texture_of_cursor, "notify::x", G_CALLBACK(on_cursor_notify_x), vault);
 
 
-
-	//FIXME: use TangleScrollingActor
-	TEXTURE_VOLUME_BACKGROUND = clutter_texture_new_from_file("/opt/jammo/sequencer/volume_background.png", NULL);
-	BUTTON_VOLUME_SLIDER =clutter_texture_new_from_file("/opt/jammo/sequencer/volume_button.png", NULL);
-
-	g_signal_connect (TEXTURE_VOLUME_BACKGROUND, "button-press-event", G_CALLBACK (pressed_sequencer_volume_background), NULL);
-	g_signal_connect (TEXTURE_VOLUME_BACKGROUND, "button-release-event", G_CALLBACK (released_sequencer_volume_background), NULL);
-	g_signal_connect (TEXTURE_VOLUME_BACKGROUND, "motion-event", G_CALLBACK (motion_sequencer_volume_background), NULL);
-
-	g_signal_connect (BUTTON_VOLUME_SLIDER, "button-press-event", G_CALLBACK (pressed_sequencer_button_volume_slider), NULL);
-	g_signal_connect (BUTTON_VOLUME_SLIDER, "button-release-event", G_CALLBACK (released_sequencer_button_volume_slider), NULL);
-	g_signal_connect (BUTTON_VOLUME_SLIDER, "motion-event", G_CALLBACK (motion_sequencer_button_volume_slider), NULL);
-
-
-	clutter_actor_set_reactive(TEXTURE_VOLUME_BACKGROUND, TRUE);
-	clutter_actor_set_reactive(BUTTON_VOLUME_SLIDER, TRUE);
-
-	ClutterActor* sequencer_track_area = jammo_get_actor_by_id("fullsequencer-track-control-panel");
-	tangle_widget_add(TANGLE_WIDGET(sequencer_track_area),TEXTURE_VOLUME_BACKGROUND,NULL);
-	tangle_widget_add(TANGLE_WIDGET(sequencer_track_area),BUTTON_VOLUME_SLIDER,NULL);
-
-	clutter_actor_hide(TEXTURE_VOLUME_BACKGROUND);
-	clutter_actor_hide(BUTTON_VOLUME_SLIDER);
+	//Hide volumebar
+	clutter_actor_hide(jammo_get_actor_by_id("fullsequencer-volumebar-container"));
 }
