@@ -43,17 +43,6 @@
 void welcome_door_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties);
 static gboolean door_timeouts(gpointer data);
 
-/*
- * Note! You need Tangle Toolkit that is available here:
- *
- * http://gitorious.org/tangle
- *
- * To compile:
- * gcc -rdynamic -o jammo jammo.c jammo-*.c $(pkg-config --cflags --libs clutter-1.0 tangle gstreamer-0.10 gstreamer-base-0.10 gstreamer-controller-0.10) ../meam/libmeam.a
- *
- * Note that -rdynamic is important in order to dynamic signal handler binding to work!
- */
-
 static ClutterScript* script;
 
 ClutterActor* jammo_get_actor_by_id(const char* id) {
@@ -66,6 +55,16 @@ ClutterActor* jammo_get_actor_by_id(const char* id) {
 	return actor;
 }
 
+GObject* jammo_get_object_by_id(const char* id) {
+	GObject* object = NULL;
+
+	if (!(object = clutter_script_get_object(script, id))) {
+		g_warning("Object '%s' not found.", id);
+	}
+	
+	return object;
+}
+
 /* A TangleStylesheet directory is tried to load from the following locations:
  * 	/opt/jammo/stylesheet
  * 	<current_working_directory>/data/stylesheet
@@ -350,7 +349,6 @@ int main(int argc, char** argv) {
 
 	clutter_main();
 
-	g_object_unref(stage);
 	g_object_unref(script);
 	g_object_unref(stylesheet);
 	
