@@ -121,9 +121,10 @@ static GstStaticPadTemplate gst_jammo_slider_src_template =
         "rate = (int) [ 1, MAX ], " "channels = (int) 1")
     );
 
-GST_BOILERPLATE (GstJammoSlider, gst_jammo_slider, GstBaseSrc,
-    GST_TYPE_BASE_SRC);
+GST_BOILERPLATE (GstJammoSlider, gst_jammo_slider, GstBaseSrc, GST_TYPE_BASE_SRC)
 
+static void gst_jammo_slider_dispose (GObject * object);
+static void gst_jammo_slider_finalize (GObject * object);
 
 static void gst_jammo_slider_set_property (GObject * object,
     guint prop_id, const GValue * value, GParamSpec * pspec);
@@ -224,6 +225,9 @@ static void gst_jammo_slider_class_init (GstJammoSliderClass * klass)
   gobject_class = (GObjectClass *) klass;
   gstbasesrc_class = (GstBaseSrcClass *) klass;
 
+	gobject_class->dispose = gst_jammo_slider_dispose;  
+	gobject_class->finalize = gst_jammo_slider_finalize;
+
   gobject_class->set_property = gst_jammo_slider_set_property;
   gobject_class->get_property = gst_jammo_slider_get_property;
 
@@ -354,22 +358,19 @@ static void gst_jammo_slider_init (GstJammoSlider * src, GstJammoSliderClass * g
 	char * path=NULL;
 	path=g_strdup_printf("%s%s",SLIDER_FOLDER,"slider_blow.wav");
 	printf("opening file %s\n", path);
+	memset(&(src->blow_file_info), 0, sizeof(SF_INFO));
 	src->blow_file = sf_open(path, SFM_READ, &(src->blow_file_info));
 	if (src->blow_file==NULL) {
 		printf("opening failed\n");
 	}
 	else {
-		// get number of frames
-		guint length = sf_seek(src->blow_file, 0, SEEK_END);
-		sf_seek(src->blow_file, 0, SEEK_SET);
-	
 		// allocate buffer
-		src->blow_table = malloc(sizeof(gint16)*length);
+		src->blow_table = malloc(sizeof(gint16)*src->blow_file_info.frames);
 	
 		// read to buffer
-		gint index=0;
-		while (sf_read_short(src->blow_file, &(src->blow_table[index]), 512)==512) {
-			index+=512;
+		if (sf_read_short(src->blow_file, src->blow_table, (src->blow_file_info).frames)
+			!= src->blow_file_info.frames) {
+				printf("error reading sample file\n");
 		}
 		sf_close(src->blow_file);
 	}
@@ -399,64 +400,7 @@ static void gst_jammo_slider_src_fixate (GstPad * pad, GstCaps * caps)
     gst_structure_fixate_field_nearest_int (structure, "width", 64);
 }
 
-static JammoSliderProcessFunc process_funcs[];
 
-static gboolean gst_jammo_slider_setcaps (GstBaseSrc * basesrc, GstCaps * caps)
-{
-  GstJammoSlider *src = GST_JAMMO_SLIDER (basesrc);
-  const GstStructure *structure;
-  const gchar *name;
-  gint width;
-  gboolean ret;
-
-  structure = gst_caps_get_structure (caps, 0);
-  ret = gst_structure_get_int (structure, "rate", &src->samplerate);
-
-  GST_DEBUG_OBJECT (src, "negotiated to samplerate %d", src->samplerate);
-
-  name = gst_structure_get_name (structure);
-  if (strcmp (name, "audio/x-raw-int") == 0) {
-    ret &= gst_structure_get_int (structure, "width", &width);
-    src->format = (width == 32) ? GST_JAMMO_SLIDER_FORMAT_S32 :
-        GST_JAMMO_SLIDER_FORMAT_S16;
-  } else {
-    ret &= gst_structure_get_int (structure, "width", &width);
-    src->format = (width == 32) ? GST_JAMMO_SLIDER_FORMAT_F32 :
-        GST_JAMMO_SLIDER_FORMAT_F64;
-  }
-
-  /* allocate a new buffer suitable for this pad */
-  switch (src->format) {
-    case GST_JAMMO_SLIDER_FORMAT_S16:
-      printf("format is now gint16\n");
-      src->sample_size = sizeof (gint16);
-      break;
-    case GST_JAMMO_SLIDER_FORMAT_S32:
-      printf("format is now gint32\n");
-      src->sample_size = sizeof (gint32);
-      break;
-    case GST_JAMMO_SLIDER_FORMAT_F32:
-      printf("format is now gfloat32\n");
-      src->sample_size = sizeof (gfloat);
-      break;
-    case GST_JAMMO_SLIDER_FORMAT_F64:
-      printf("format is now gfloat32\n");
-      src->sample_size = sizeof (gdouble);
-      break;
-    default:
-      /* can't really happen */
-      ret = FALSE;
-      break;
-  }
-
-  if (src->format == -1) {
-    src->process = NULL;
-    return FALSE;
-  }
-  src->process = process_funcs[src->format];
-
-  return ret;
-}
 
 static gboolean gst_jammo_slider_query (GstBaseSrc * basesrc, GstQuery * query)
 {
@@ -522,6 +466,21 @@ error:
   }
 }
 
+static void
+gst_jammo_slider_dispose (GObject * object)
+{
+	GstJammoSlider *src = GST_JAMMO_SLIDER (object);
+	g_free(src->blow_table);
+	jammo_slider_event_free_glist(&(src->eventlist));
+  G_OBJECT_CLASS (parent_class)->dispose (object);
+}
+
+static void
+gst_jammo_slider_finalize (GObject * object)
+{
+  G_OBJECT_CLASS (parent_class)->finalize (object);
+}
+
 /*This array is automatic generated with freq_util.c*/
 /*It is based on facts (=supposition) 
 a) there are 12 notes on one octave
@@ -774,7 +733,6 @@ static void gst_jammo_slider_process_##type (GstJammoSlider * src, g##type * sam
 \
 		if (src->blow_accumulator > src->blow_loop_end) { \
 			src->blow_accumulator=src->blow_loop_start; \
-			sf_seek(src->blow_file, src->blow_loop_start, SEEK_SET); \
 		} \
 \
 		/* if playing, process ADSR */ \
@@ -827,10 +785,10 @@ static void gst_jammo_slider_process_##type (GstJammoSlider * src, g##type * sam
 	}\
 }
 
-DEFINE_PROCESS (int16, 32767.0);
-DEFINE_PROCESS (int32, 2147483647.0);
-DEFINE_PROCESS (float, 1.0);
-DEFINE_PROCESS (double, 1.0);
+DEFINE_PROCESS (int16, 32767.0)
+DEFINE_PROCESS (int32, 2147483647.0)
+DEFINE_PROCESS (float, 1.0)
+DEFINE_PROCESS (double, 1.0)
 
 
 static JammoSliderProcessFunc process_funcs[] = {
@@ -840,6 +798,62 @@ static JammoSliderProcessFunc process_funcs[] = {
   (JammoSliderProcessFunc) gst_jammo_slider_process_double
 };
 
+static gboolean gst_jammo_slider_setcaps (GstBaseSrc * basesrc, GstCaps * caps)
+{
+  GstJammoSlider *src = GST_JAMMO_SLIDER (basesrc);
+  const GstStructure *structure;
+  const gchar *name;
+  gint width;
+  gboolean ret;
+
+  structure = gst_caps_get_structure (caps, 0);
+  ret = gst_structure_get_int (structure, "rate", &src->samplerate);
+
+  GST_DEBUG_OBJECT (src, "negotiated to samplerate %d", src->samplerate);
+
+  name = gst_structure_get_name (structure);
+  if (strcmp (name, "audio/x-raw-int") == 0) {
+    ret &= gst_structure_get_int (structure, "width", &width);
+    src->format = (width == 32) ? GST_JAMMO_SLIDER_FORMAT_S32 :
+        GST_JAMMO_SLIDER_FORMAT_S16;
+  } else {
+    ret &= gst_structure_get_int (structure, "width", &width);
+    src->format = (width == 32) ? GST_JAMMO_SLIDER_FORMAT_F32 :
+        GST_JAMMO_SLIDER_FORMAT_F64;
+  }
+
+  /* allocate a new buffer suitable for this pad */
+  switch (src->format) {
+    case GST_JAMMO_SLIDER_FORMAT_S16:
+      printf("format is now gint16\n");
+      src->sample_size = sizeof (gint16);
+      break;
+    case GST_JAMMO_SLIDER_FORMAT_S32:
+      printf("format is now gint32\n");
+      src->sample_size = sizeof (gint32);
+      break;
+    case GST_JAMMO_SLIDER_FORMAT_F32:
+      printf("format is now gfloat32\n");
+      src->sample_size = sizeof (gfloat);
+      break;
+    case GST_JAMMO_SLIDER_FORMAT_F64:
+      printf("format is now gfloat32\n");
+      src->sample_size = sizeof (gdouble);
+      break;
+    default:
+      /* can't really happen */
+      ret = FALSE;
+      break;
+  }
+
+  if (src->format == -1) {
+    src->process = NULL;
+    return FALSE;
+  }
+  src->process = process_funcs[src->format];
+
+  return ret;
+}
 
 static void gst_jammo_slider_get_times (GstBaseSrc * basesrc, GstBuffer * buffer,
     GstClockTime * start, GstClockTime * end)
@@ -881,6 +895,7 @@ static gboolean gst_jammo_slider_start (GstBaseSrc * basesrc)
   src->tremolo_phase = 0;
 	src->adsr_counter=0;
 	src->accumulator=0;
+  src->time = 0;
 
   //realtime recording
   if (src->recording) {
@@ -923,6 +938,28 @@ static gboolean gst_jammo_slider_do_seek (GstBaseSrc * basesrc, GstSegment * seg
   segment->time = segment->start;
   time = segment->last_stop;
 
+	// seek eventlist to correct position
+	src->time = segment->time;
+	src->playback_index_for_event=0;
+	JammoSliderEvent * event =NULL;
+	while (1) {
+		event=g_list_nth_data(src->eventlist,src->playback_index_for_event);
+		// stop seeking if all events seeked
+		if (event==NULL) {
+			break;
+		}
+		// stop seeking if next event is before current time
+		if (src->time <= event->timestamp) {
+			break;
+		}
+		// no need to stop seeking yet
+		src->playback_index_for_event+=1;
+	}
+	// turn sound off
+	src->released=TRUE;
+	src->rounding_counter=0;
+	src->rounded=FALSE;
+
   /* now move to the time indicated */
   src->next_sample =
       gst_util_uint64_scale_int (time, src->samplerate, GST_SECOND);
@@ -1209,6 +1246,9 @@ static void gst_jammo_slider_set_property (GObject * object, guint prop_id,
       break;
     case PROP_RECORDING:
       src->recording = g_value_get_boolean (value);
+      // when playbacking slider needs to be not is-live so that seeking works better
+      // when recording slider needs to be is-live for smoother response
+      gst_base_src_set_live (GST_BASE_SRC (src), g_value_get_boolean (value));
       break;
    case PROP_EVENTLIST:
       //We got GList containing JammoSliderEvents, take all one-by-one and add to own internal eventlist
